FrontFaceLeadForm class

Inheritance

Constructors

FrontFaceLeadForm({Key? key, required FrontFaceEmbedConfig config, required FrontFaceChatTheme theme, required FrontFaceChatStrings strings, required Future<void> onSubmit(String email, String? field2, String? field3), double bottomInset = 0})
const

Properties

bottomInset double
Extra bottom padding so the submit button clears the home indicator / host bottom nav when the composer is not shown.
final
config FrontFaceEmbedConfig
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onSubmit Future<void> Function(String email, String? field2, String? field3)
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
strings FrontFaceChatStrings
final
theme FrontFaceChatTheme
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<FrontFaceLeadForm>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited