FrontFaceChatConfig class
Credentials and settings for your FrontFace project.
Get projectId and publishableKey from the FrontFace dashboard under Mobile SDK.
Constructors
- FrontFaceChatConfig({required String projectId, required String publishableKey, String baseUrl = 'https://api.frontface.app', bool debugLogging = false, bool requireLeadCaptureBeforeChat = true, String? visitorId, bool showNewChatButton = true, FrontFaceAttachmentsConfig attachments = FrontFaceAttachmentsConfig.disabled})
-
const
Properties
- attachments → FrontFaceAttachmentsConfig
-
Optional attachments (location / images / voice). Defaults off.
final
- baseUrl → String
-
API base URL. Defaults to production.
final
- debugLogging → bool
-
Enable debug console logs (curl + responses). Defaults to
false.final - hashCode → int
-
The hash code for this object.
no setterinherited
- projectId → String
-
FrontFace project UUID (NOT the
pk_key).final - publishableKey → String
-
Publishable mobile SDK key (
pk_…).final - requireLeadCaptureBeforeChat → bool
-
Shows the lead-capture form (email/phone/etc.) before the first
message and before any conversation/session is created.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- showNewChatButton → bool
-
Shows the app-bar refresh (“new chat”) button. Defaults to
true.final - visitorId → String?
-
Optional account-keyed visitor id for logged-in users.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited